AUTHORS
=======

Created By
----------
#. `shaunsephton <http://github.com/shaunsephton>`_

Contributors
------------
#. `loop0 <http://github.com/loop0>`_
#. `chr15m <http://github.com/chr15m>`_
#. `buchuki <http://github.com/buchuki>`_

